( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-accessories.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf accessories.svg redhat-accessories.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf system-tools-32.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf icon-system-tools.svg system-tools-32.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-system_tools.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf icon-system-tools.svg redhat-system_tools.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-system_settings.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf advanced-directory.svg redhat-system_settings.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf up2date.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf downloadmanager.svg up2date.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf thunderbird.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf email.svg thunderbird.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-preferences.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-settings.svg redhat-preferences.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf evolution-1.4.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf evolution.svg evolution-1.4.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-home.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-home.svg redhat-home.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-gaim.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gaim.svg gnome-gaim.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gcalctool.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-calc3.svg gcalctool.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gedit-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gedit.svg gedit-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-palette.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gimp.svg gnome-palette.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-gimp.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gimp.svg gnome-gimp.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf wilber-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gimp.svg wilber-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-mouse.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf mouse-capplet.svg gnome-mouse.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-web-browser.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf mozilla-icon.svg redhat-web-browser.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf mozilla-star.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf mozilla-icon.svg mozilla-star.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf mozilla.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf mozilla-icon.svg mozilla.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf mozilla-orig.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf mozilla-icon.svg mozilla-orig.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-office.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-applications.svg redhat-office.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-cdplayer-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-cdplayer.svg gnome-cdplayer-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-programming.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-devel.svg redhat-programming.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-config-xfree86.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf monitor.svg redhat-config-xfree86.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-starthere.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf my-computer.svg gnome-starthere.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-email.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf evolution.svg redhat-email.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-games.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-joystick.svg redhat-games.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-graphics.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-graphics.svg redhat-graphics.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-envelope.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf email.svg gnome-envelope.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf mozilla-mail-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf email.svg mozilla-mail-icon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf web-browser.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-globe.svg web-browser.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-internet.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-globe.svg redhat-internet.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-main-menu.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-logo.svg redhat-main-menu.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gnome-main-menu.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-logo.svg gnome-main-menu.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf redhat-sound_video.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-multimedia.svg redhat-sound_video.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf gripicon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf sound-juicer.svg gripicon.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; rm -rf xpdf.svg )
( cd usr/share/icons/Amaranth/scalable/apps ; ln -sf gnome-pdf.svg xpdf.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; ln -sf gnome-mime-audio.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; ln -sf gnome-compressed.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; rm -rf gnome-mime-application-x-tgz.svg )
( cd usr/share/icons/Amaranth/scalable/mimetypes ; ln -sf gnome-compressed.svg gnome-mime-application-x-tgz.svg )
( cd usr/share/icons/Gorilla/scalable/apps ; rm -rf gnome-joystick.svg )
( cd usr/share/icons/Gorilla/scalable/apps ; ln -sf gnome-games.svg gnome-joystick.svg )
( cd usr/share/icons/Gorilla/scalable/apps ; rm -rf galeon.svg )
( cd usr/share/icons/Gorilla/scalable/apps ; ln -sf web-browser.svg galeon.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-compressed.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-application-vnd.ms-excel.svg gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-audio.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-video-x-msvideo.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-video.svg gnome-mime-video-x-msvideo.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-video-quicktime.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-video.svg gnome-mime-video-quicktime.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-video-x-ms-wmv.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-video.svg gnome-mime-video-x-ms-wmv.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-video-mpeg.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-video.svg gnome-mime-video-mpeg.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; rm -rf gnome-mime-application-x-php.svg )
( cd usr/share/icons/Gorilla/scalable/mimetypes ; ln -sf gnome-mime-text-html.svg gnome-mime-application-x-php.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-email.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf evolution-1.4.svg redhat-email.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf evolution.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf evolution-1.4.svg evolution.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf gnome-palette.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-gimp.svg gnome-palette.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf wilber-icon.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-gimp.svg wilber-icon.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf mozilla-star.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mozilla.svg mozilla-star.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf mozilla-orig.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mozilla.svg mozilla-orig.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-web-browser.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mozilla.svg redhat-web-browser.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf mozilla--mail.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mozilla-mail-icon.svg mozilla--mail.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf mozilla-composer.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mozilla-compose-icon.svg mozilla-composer.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-office.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-applications.svg redhat-office.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-accessories.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf accessories.svg redhat-accessories.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-home.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf my-computer.svg redhat-home.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf gedit-icon.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gedit.svg gedit-icon.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf thunderbird.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-envelope.svg thunderbird.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-games.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-joystick.svg redhat-games.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-graphics.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-graphics.svg redhat-graphics.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-internet.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-globe.svg redhat-internet.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-main-menu.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-logo.svg redhat-main-menu.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf gnome-main-menu.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-logo.svg gnome-main-menu.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-sound_video.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-multimedia.svg redhat-sound_video.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-programming.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-devel.svg redhat-programming.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-preferences.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-ccdesktop.svg redhat-preferences.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf gnome-mouse.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mouse-capplet.svg gnome-mouse.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-system_settings.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-system-config.svg redhat-system_settings.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-system_tools.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-system.svg redhat-system_tools.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf gnome-audio.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf gnome-mixer.svg gnome-audio.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-spreadsheet.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf ooo_calc.svg redhat-spreadsheet.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-presentations.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf ooo_impress.svg redhat-presentations.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf redhat-word-processor.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf ooo_writer.svg redhat-word-processor.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf inkscape.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf sodipodi.svg inkscape.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf maelstrom.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf kasteroids.svg maelstrom.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; rm -rf mplayer-logo.svg )
( cd usr/share/icons/Nuvola/scalable/apps ; ln -sf mplayer.svg mplayer-logo.svg )
( cd usr/share/icons/Nuvola/scalable/devices ; rm -rf gnome-dev-mouse-optical.svg )
( cd usr/share/icons/Nuvola/scalable/devices ; ln -sf gnome-dev-mouse.svg gnome-dev-mouse-optical.svg )
( cd usr/share/icons/Nuvola/scalable/devices ; rm -rf gnome-dev-removable.svg )
( cd usr/share/icons/Nuvola/scalable/devices ; ln -sf gnome-dev-cdwriter.svg gnome-dev-removable.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; ln -sf gnome-compressed.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; rm -rf gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; ln -sf gnome-mime-application-vnd.ms-excel.svg gnome-mime-application-x-gnumeric.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/Nuvola/scalable/mimetypes ; ln -sf gnome-mime-audio.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-compressed.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-audio.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; rm -rf gnome-mime-application-x-php.svg )
( cd usr/share/icons/Lush/scalable/mimetypes ; ln -sf gnome-mime-text-html.svg gnome-mime-application-x-php.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf gnome-palette.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf gnome-gimp.svg gnome-palette.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf wilber-icon.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf gnome-gimp.svg wilber-icon.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf redhat-web-browser.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf mozilla-star.svg redhat-web-browser.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf mozilla.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf mozilla-star.svg mozilla.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf mozilla-orig.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf mozilla-star.svg mozilla-orig.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf gnome-envelope.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf evolution.svg gnome-envelope.svg )
( cd usr/share/icons/Lush/scalable/apps ; rm -rf evolution-1.4.svg )
( cd usr/share/icons/Lush/scalable/apps ; ln -sf evolution.svg evolution-1.4.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf system-tools-32.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf advanced-directory.svg system-tools-32.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf xmms.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-audio2.svg xmms.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf gnome-media-player.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-audio2.svg gnome-media-player.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf gnome-palette.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-gimp.svg gnome-palette.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf wilber-icon.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-gimp.svg wilber-icon.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf evolution-1.4.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-envelope.svg evolution-1.4.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-email.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-envelope.svg redhat-email.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf thunderbird.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-envelope.svg thunderbird.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-web-browser.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf mozilla-star.svg redhat-web-browser.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf mozilla.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf mozilla-star.svg mozilla.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf mozilla-orig.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf mozilla-star.svg mozilla-orig.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-office.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-applications.svg redhat-office.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-home.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-home.svg redhat-home.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-games.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-joystick.svg redhat-games.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf web-browser.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-globe.svg web-browser.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-internet.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-globe.svg redhat-internet.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-main-menu.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-logo.svg redhat-main-menu.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf gnome-main-menu.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-logo.svg gnome-main-menu.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-sound_video.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-multimedia.svg redhat-sound_video.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-programming.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-devel.svg redhat-programming.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf redhat-preferences.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-ccdesktop.svg redhat-preferences.svg )
( cd usr/share/icons/Wasp/scalable/apps ; rm -rf gaim.svg )
( cd usr/share/icons/Wasp/scalable/apps ; ln -sf gnome-gaim.svg gaim.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-package.svg gnome-mime-application-x-stuffit.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-ttf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-pcf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-type1.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-linux-psf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-bdf.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-application-x-font.svg gnome-mime-application-x-font-afm.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-ogg.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-audio.svg gnome-mime-application-ogg.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; rm -rf gnome-mime-application-x-php.svg )
( cd usr/share/icons/Wasp/scalable/mimetypes ; ln -sf gnome-mime-text-html.svg gnome-mime-application-x-php.svg )

for i in Amaranth Gorilla Nuvola Lush Wasp
do
    if [ -e usr/share/icons/$i/icon-theme.cache ]; then
        rm -f usr/share/icons/$i/icon-theme.cache
    fi
	usr/bin/gtk-update-icon-cache usr/share/icons/$i
done

